@@ -1,6 +1,6 @@
 #' Decompose taxon letter codes
 #'
-#' @description Find all codes that logically comprise the specified codes. For instance, code "ABC" ("Anhyturbels") returns "A" ("Gelisols"), "AB" ("Turbels"), "ABC" ("Anhyturbels"). Use in conjunction with a lookup table that maps Order, Suborder, Great Group and Subgroup taxa to their codes (see \code{\link{taxon_code_to_taxon}} and \code{\link{taxon_to_taxon_code}}).
+#'  Find all codes that logically comprise the specified codes. For instance, code "ABC" ("Anhyturbels") returns "A" ("Gelisols"), "AB" ("Turbels"), "ABC" ("Anhyturbels"). Use in conjunction with a lookup table that maps Order, Suborder, Great Group and Subgroup taxa to their codes (see \code{\link{taxon_code_to_taxon}} and \code{\link{taxon_to_taxon_code}}).
 #'
 #' @details Accounts for Keys that run out of capital letters (more than 26 subgroups) and use lowercase letters for a unique subdivision within the "fourth character position."
 #'
@@ -49,7 +49,7 @@ decompose_taxon_code <- function(codes) {
 
 #' Get taxon codes of preceding taxa
 #'
-#' @description Find all codes that logically precede the specified codes. For instance, code "ABC" ("Anhyturbels") returns "AA" ("Histels") "ABA" ("Histoturbels") and "ABB" ("Aquiturbels"). Use in conjunction with a lookup table that maps Order, Suborder, Great Group and Subgroup taxa to their codes (see \code{\link{taxon_code_to_taxon}} and \code{\link{taxon_to_taxon_code}}).
+#'  Find all codes that logically precede the specified codes. For instance, code "ABC" ("Anhyturbels") returns "AA" ("Histels") "ABA" ("Histoturbels") and "ABB" ("Aquiturbels"). Use in conjunction with a lookup table that maps Order, Suborder, Great Group and Subgroup taxa to their codes (see \code{\link{taxon_code_to_taxon}} and \code{\link{taxon_to_taxon_code}}).
 #'
 #' @details  Accounts for Keys that run out of capital letters (more than 26 subgroups) and use lowercase letters for a unique subdivision within the "fourth character position."
 #'
@@ -187,7 +187,7 @@ taxon_to_taxon_code <- function(taxon) {
 
 #' Determine relative position of taxon within Keys to Soil Taxonomy (Order to Subgroup)
 #'
-#' @description The relative position of a taxon is `[number of preceding Key steps] + 1`, or `NA` if it does not exist in the lookup table.
+#'  The relative position of a taxon is `[number of preceding Key steps] + 1`, or `NA` if it does not exist in the lookup table.
 #'
 #' @param code A character vector of taxon codes to determine the relative position of.
 #'
@@ -238,7 +238,7 @@ relative_taxon_code_position <- function(code) {
   }
 
   ST_higher_taxa_codes_12th <- NULL
-  load(system.file("data/ST_higher_taxa_codes_12th.rda", package = "SoilTaxonomy")[1])
+  load(system.file("data", "ST_higher_taxa_codes_12th.rda", package = "SoilTaxonomy")[1])
 
   # for efficiency the lowercase taxon names are calculated only if needed
   # the ST_higher_taxa_codes loading function does this
